@@ -72,3 +72,11 @@ def set_deal_for_line_item(line_item_id, deal_id):
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to set deal for line item. Result: {result}")
   return result
+
+
+def set_contact_for_meeting(meeting_id, contact_id):
+  post_url = f"{BASE_URL}crm/v3/objects/meetings/{meeting_id}/associations/contacts/{contact_id}/MEETING_EVENT_TO_CONTACT"
+  result = put(post_url, HEADERS)
+  if not Utils.is_success(result['status_code']):
+    raise Exception(f"Failed to set contact for meeting. Result: {result}")
+  return result
