@@ -149,6 +149,14 @@ def update_contacts_batch(contacts):
   return result
 
 
+def delete_contact(contact_id):
+  post_url = f"{BASE_URL}crm/v3/objects/contacts/{contact_id}"
+  result = delete(post_url, HEADERS)
+  if not Utils.is_success(result['status_code']):
+    raise Exception(f"Failed to delete contact. Result: {result}")
+  return result
+
+
 def unsubscribe_from_all(contact_email):
   post_url = f"{BASE_URL}email/public/v1/subscriptions/{contact_email}"
   post_body = {
