@@ -1,5 +1,6 @@
 from ringcentral import SDK
 import time
+import math
 
 
 BASE_URL = 'https://platform.ringcentral.com'
@@ -36,15 +37,18 @@ class ringcentral:
       elif method.lower() == 'delete':
         result = self.platform.delete(url)
     except Exception as e:
-      wait = 60
+      wait = 64
       error_message = str(e)
       while (
           'Request rate exceeded' in error_message
           or '429' in error_message
       ):
-        print(f"retrying. last result: {str(e)}")
-        time.sleep(wait)
-        wait = wait * 2 if wait < 1000 else 1000
+        print(f"retrying. last result: {str(e)} {method} {url} {query_params} {payload}")
+        # Keep connection alive every minute
+        for i in range(0, math.floor(wait / 32)):
+          print(f"Waiting at {i * 32} seconds...")
+          time.sleep(32)
+        wait = wait * 2 if wait < 1024 else 1024
         try:
           if method.lower() == 'get':
             result = self.platform.get(url, query_params)
