@@ -42,6 +42,6 @@ def create_task(project, location, queue, relative_handler_uri, payload=None, in
     task['schedule_time'] = timestamp
 
   # Use the client to build and send the task.
-  response = client.create_task(parent, task)
+  response = client.create_task(parent=parent, task=task)
   return response
 # [END cloud_tasks_appengine_create_task]
